<?php
/**
 * Plugin Name: Spanish Quotes of the Day (Frase del Día)
 * Plugin URI:
 * Description: This plugin creates a Widget and a Shortcode that give random quotes in spanish from <a href="http://todopensamientos.com">Todopensamientos</a>
 * Version: 1.2.2
 * Author: Joan Miquel Viadé
 * Text Domain: spanish-quotes-of-the-day
 * Author URI: http://www.joanmiquelviade.com/joan-miquel-viade/
 * License: GPLv2 or later
 * Tags: quotes, spanish, spanish quotes, quote of the day, random quotes, frases, frase del dia, frases aleatorias, frases en español, citas en español, citas, frases célebres, oembed
*/
?>
<?php
// initialize version number
global $spn_quotes_ver;
$spn_quotes_ver = '1.2.2';

// The interface Class 
class spn_quotes_interface {
	
	function __construct() {

		add_action( 'admin_menu', array( $this, 'spanish_quotes_menu_init' ) );
		add_action( 'admin_init', array( $this, 'spanish_quotes_settings_init' ) );
		
	}

	function spanish_quotes_settings_init() {
		
		add_settings_section(
			'spnq_general_section',
			__('General Options', 'spanish-quotes-of-the-day'),
			array( $this, 'spnq_general_setting_section_callback'),
			'spanish_quotes_settings'
		);

		add_settings_field(
			'spnq_quote_length_field',
			__('Maximum Length', 'spanish-quotes-of-the-day'),
			array( $this, 'spnq_quote_length_field_callback'),
			'spanish_quotes_settings',
			'spnq_general_section'
		);
						   
		register_setting( 'spanish_quotes_settings', 'spnq_quote_length_field' );

		add_settings_field(
			'spnq_async_mode_field',
			__('Asyncronous Mode', 'spanish-quotes-of-the-day'),
			array( $this, 'spnq_async_mode_field_callback'),
			'spanish_quotes_settings',
			'spnq_general_section'
		);
		
		register_setting( 'spanish_quotes_settings', 'spnq_async_mode_field' );

	}

	function spnq_general_setting_section_callback() {
	}

	function spnq_quote_length_field_callback() {
		
		$length = get_option( 'spnq_quote_length_field' );
		if ( $length == '' ) $length = 275;
		
		echo '<input name="spnq_quote_length_field" id="spnq_quote_length_field_id" type="number" value="' . $length . '" class="number" min="40" />&nbsp;&nbsp;<span class="description">' . __('Introduce the maximum length for the quotes in characters. Default value, <strong>275</strong>. (The minimum length is set to 40)', 'spanish-quotes-of-the-day') . '</span><br />';
		
	}

	function spnq_async_mode_field_callback() {
		
		echo '<input name="spnq_async_mode_field" id="spnq_async_mode_field_id" type="checkbox" value="1" class="code" ' . checked( 1, get_option( 'spnq_async_mode_field' ), false ) . ' /><span class="description">' . __('Check this field to activate the asynchronous fetching operation mode.', 'spanish-quotes-of-the-day') . '</span><br /><br />';

		echo '<p>' . __('The Asynchronous Fetching Operation Mode produces a better average page load performance however, this mode could be <strong>incompatible with some client side systems</strong> and, in addition, some times it\'s a much less stable. We advise you <strong>do not activate</strong> the asynchronous mode unless your website <strong>really</strong> has a high level of hits per day (>40,000). By default, the asynchronous fetching operation mode is disabled.', 'spanish-quotes-of-the-day') . '</p>';

	}

 	function spanish_quotes_menu_init () {
		
		add_options_page(	__('Spanish Quotes of the Day', 'spanish-quotes-of-the-day'), 
							__('Spanish Quotes', 'spanish-quotes-of-the-day'),
							'manage_options', 
							'spanish_quotes_settings', 
						 	array( $this, 'spanish_quotes_render_settings_page' ) 
						);
		
	}
	
	function  spanish_quotes_render_settings_page () {
		
		echo '<div class="wrap">';
		echo '<h2>' . __('Spanish Quotes of the Day', 'spanish-quotes-of-the-day') . '</h2>';
        echo '<form action="options.php" method="POST">';
        settings_fields( 'spanish_quotes_settings' );
        do_settings_sections( 'spanish_quotes_settings' );
        submit_button();
        echo '</form><!-- "form" -->';
		echo '</div><!-- ".wrap" -->';
		
	}
	
}
if ( is_admin() ) new spn_quotes_interface;


// Widget Class 
class spn_quotes extends WP_Widget {

	public $version;
	
	// Construction
	function __construct( ) {
		
		// basic vars for translated versions
		$title 			= __('Spanish Quotes of the Day', 'spanish-quotes-of-the-day');
		$description 	= __('Add a random Quote of the Day in spanish to your website.', 'spanish-quotes-of-the-day' );
		$shortcode      = __('spanish_quote', 'spanish-quotes-of-the-day');
		$this->version  = $spn_quotes_ver;
		
		// Constructing the widget
		parent::__construct( 'quotes', $title, array( 'description' => $description ) );
		
		// in front-end WP loads add the mininum styles
		if ( ! is_admin() )
			wp_enqueue_style( "spanish-quotes", plugins_url( 'css/spanish-quotes.css' , __FILE__ ) );

		// the basic shortcode 'spanish_quote' is always avaiable
		add_shortcode ( 'spanish_quote', array( $this, 'quotes_shortcode' ));
		// adding a shorcode translated to the local language
		if ( WPLANG != 'en_US')
			add_shortcode ( $shortcode, array( $this, 'quotes_shortcode' ));

	}

	// Widget Front-End
	public function widget( $args, $instance ) {
		
		global $post;
		
		$title = apply_filters( 'widget_title', $instance['title'] );
		// before and after widget arguments are defined by themes
		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title'];
		
		// Fetching the Spanish Quote
		$response = $this->fetch_quotes();
		
		// Filtering the results for output through Widget
		echo apply_filters ( 'widget_quotes', $response , $post );
		
		echo $args['after_widget'];
		
	}
	
	// Widget Back-End 
	public function form( $instance ) {
		if ( isset( $instance[ 'title' ] ) ) {
			$title = $instance[ 'title' ];
		}
		else {
			$title = __( 'New title', 'spanish-quotes-of-the-day' );
		}
		// the Widget admin form
		echo '<p>';
		echo '<label for="' . $this->get_field_id( 'title' ) .'">'. __( 'Title' ) . '</label>';
		echo '<input class="widefat" id="'. $this->get_field_id( 'title' ) .'" name="' . $this->get_field_name( 'title' ) . '" type="text" value="' . esc_attr( $title ) . '" />';
		echo '</p>';
	}
		
	// Updating Widget
	public function update( $new_instance, $old_instance ) {
		
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		return $instance;
	}
	
	// The oembed call 
	public function fetch_quotes() {
		
		$async_mode = get_option( 'spnq_async_mode_field' );

		// In asysnchronous mode we send the javascript code with as a response
		if ( $async_mode ) {
			
			// Seed() generates a unique random indentifier for each quote block to the jQuery recognition in a multiuse / multicall environtments
			$seed = rand();
			
//dump the jQuery code			
?>		
<script>jQuery(document).ready(function($) { $.ajax({ url : 'http://todopensamientos.com/oembed/?&callback=?', dataType : "jsonp", cache : false, async : true, type : "GET", crossDomain: true, headers : { 'X-Requested-With': 'XMLHttpRequest' }, contentType: "application/json; charset=utf-8", xhrFields: { withCredentials: true }, error : function ( result ) { alert ( "ERROR " + JSON.stringify( result ) ); return false; }, complete : function ( result ) { }, success  : function ( result ) { var quote =  JSON.parse(result); $('#quote-<?php echo $seed; ?>').find('.quote-text').html( quote.html ); $('#quote-<?php echo $seed; ?>').find('.quote-author-link').html( '<a href="' + quote.author_url + '" target="_blank" title="<? echo __( 'Notable quotes of', 'spanish-quotes-of-the-day' );?>' + ' ' + quote.author_name + ' | Todopensamientos" >' + quote.author_name + '</a>' ); } }); });</script>
<?php

			// Sending the <DIV> with a random numbered id
			return '<div id="quote-' . $seed . '" class="spn-quote-seed" >';

		// In synchronous mode we send the Oembed Response	
		} else {
 
			global $post;
			
			$length = get_option( 'spnq_quote_length_field' );
			if ( $length == '' ) $length = 275;
			
			// Fetching the Spanish Quote in raw
			$raw_response = json_decode( trim( wp_remote_retrieve_body( wp_remote_post('http://todopensamientos.com/oembed/?&length=' . $length ))));

/*
 *          The object $response format
 *			
 *			json Array {
 *				'version' 		=> "1.0",
 *				'type'			=> "rich",
 *				'html'			=> quote's contents,
 *				'url'			=> exact URL of quote's page, 
 *				'provider_name' => "TodoPensamientos",
 *				'provider_url'	=> URL's provider,
 *				'author_name'	=> AuthorName,
 *				'author_url'	=> exact URL of author's archive page,
 *			} 
 */
 
 			// Filtering raw results for spacial needs...
			return apply_filters ( 'raw_quotes', $raw_response, $post );
			
		}
		
	}
	
	// call for Shortcodes 
	public function quotes_shortcode () {
		
		global $post;
		
		// Fetching the Spanish Quote
		$response = $this->fetch_quotes();
		
		// Filtering the results for output through Shortcode
		return apply_filters ( 'post_quotes', $response, $post );
		
	}

	// basic quote formating
	public function cook_quotes ( $response, $post ) {

		$async_mode = get_option( 'spnq_async_mode_field' );
		
		// asynchronous mode cooking without content, only HTML tags
		if ( $async_mode ) {

			// Adding a <DIV> with a random numbered id to the jQuery recognition in a multiuse / multicall environtment
			$out 	 = $response;
			
			$out 	.= '<div id="cool-quote">';
			$out 	.= '<span class="quote-text"></span> - ';
			$out 	.= '<span class="quote-author-link"></span>';
			
		// synchronous mode cooking HTML Tags and content
		} else {

			$out 	= '<div id="cool-quote">';
			$out 	.= '<span class="quote-text">'. $response->html . '</span> - ';
			$out 	.= '<span class="quote-author-link"><a href="' . $response->author_url . '" title="' . __( 'Notable quotes of', 'spanish-quotes-of-the-day' ) . ' ' . $response->author_name . ' | ' . $response->provider_name . '" target="_blank" >' . $response->author_name . '</a></span>';
			
		}

		$out 	.= '<span class="quote-credits"><a href="http://todopensamientos.com" target="_blank" title="' . __( 'Theme classified notable quotes in spanish', 'spanish-quotes-of-the-day' ) . ' | TodoPensamientos">'. __('Notable Quotes in Spanish', 'spanish-quotes-of-the-day') . '</a></span>';
		$out 	.= '</div>';
		
		// Closing the <DIV> with a random numbered id
		if ( $async_mode ) $out .= '</div>';

		return $out;
	
	}

	// Only show basic documentation on activation
	public function on_activation() {
		add_option ('cool-quotes', 'installed' );
	}

	// To create the activation message
	public function on_activation_msg () {
		
		global $spn_quotes_ver;
		
		$a = get_option ('cool-quotes');
		if ( $a ) {
			
			spn_quote_msg::show_msg ( 'ini' );
			spn_quote_msg::show_msg ( 'activated' );
			spn_quote_msg::show_msg ( 'widget' );
			spn_quote_msg::show_msg ( 'shortcode' );
			spn_quote_msg::show_msg ( 'settings-page' );
			spn_quote_msg::show_msg ( 'calling-plugin-via-function' );
			spn_quote_msg::show_msg ( 'documentation' );
			spn_quote_msg::show_msg ( 'end' );
			
			delete_option ('cool-quotes');
			update_option ('cool-quotes-ver', $spn_quotes_ver );
			
		} else {
			
			$a = get_option ('cool-quotes-ver');
			if ( ( $a == '' ) || ( $spn_quotes_ver > $a ) ) {
	
				spn_quote_msg::show_msg ( 'ini' );
				spn_quote_msg::show_msg ( 'updated' );
				spn_quote_msg::show_msg ( 'what-is-new' );
					spn_quote_msg::show_msg ( 'maximum-length' );
					spn_quote_msg::show_msg ( 'settings-page' );
				spn_quote_msg::show_msg ( 'documentation' );
				spn_quote_msg::show_msg ( 'end' );
				
				update_option ('cool-quotes-ver', $spn_quotes_ver );
				
			}
		
		}
		
	}
	
} // Class spn_quotes END


class spn_quote_msg {

	public function show_msg ( $message ) {

		global $spn_quotes_ver;
		
		switch ( $message ) {
			case 'ini' :
				echo '<div class="updated">';
				break;
				
			case 'end' :
				echo '<br /></div>';
				break;
				
			case 'activated' :
				// Succesfull installation message
				$out = sprintf ( '<p><strong>%s</strong> %s <strong>%s</strong> %s</p>', 
								__('Spanish Quote of the Day', 'spanish-quotes-of-the-day'),
								__('version', 'spanish-quotes-of-the-day'),
								$spn_quotes_ver,
								__('was succesfully activated.', 'spanish-quotes-of-the-day')
								);
				echo $out;				
				break;


			case 'updated' : 
				// Succesfull updated message
				$out = sprintf ( '<p><strong>%s</strong> %s <strong>%s</strong>.</p>', 
								__('Spanish Quote of the Day', 'spanish-quotes-of-the-day'), 
								__('was succesfully updated to the version', 'spanish-quotes-of-the-day'), 
								$spn_quotes_ver );
				echo $out;				
				break;

			case 'widget' :
				// Widget message
				$out  = sprintf( '<h4>%s</h4>', __('Widget', 'spanish-quotes-of-the-day'));
				$out .= sprintf( '<p>%s <a href="%s" target="_blank"><strong>%s</strong></a> %s <strong>%s</strong> %s',
								__('To show Spanish Quotes of the day inside your WP Theme, go to Appearance >', 'spanish-quotes-of-the-day'), 
								admin_url('widgets.php'), 
								__('Widgets', 'spanish-quotes-of-the-day'),
								__('and add the widget', 'spanish-quotes-of-the-day'),
								__('Spanish Quote of the Day', 'spanish-quotes-of-the-day'),
								__('where you prefer in any of your theme sidebars.', 'spanish-quotes-of-the-day')
								);	
				echo $out;
				break;

			case 'shortcode' :
				// Shortcode message
				$out  = sprintf( '<h4>%s</h4>', __('Shortcode', 'spanish-quotes-of-the-day'));
				$out .= '<p>';
				$out .= sprintf( '%s', 
								__('To show Spanish Quotes of the day in your Posts, Pages or Custom Post Types simply add the shortcode <code>[spanish_quote]</code> in any place of the content using the editor.', 'spanish-quotes-of-the-day')
								);
				
				if ( WPLANG != 'en_US' ) {
					$out .= sprintf( ' %s <strong>%s</strong> %s <code>[%s]</code>. %s', 				
									__('In the translated versions of Wordpress, you have also a translated version of the shortcode, that in your local language', 'spanish-quotes-of-the-day'),
									WPLANG,
									__('is', 'spanish-quotes-of-the-day'),
									__('spanish_quote', 'spanish-quotes-of-the-day'),
									__('Both of them are available.', 'spanish-quotes-of-the-day')
									);
				}
				$out .= sprintf ( ' <a href="http://codex.wordpress.org/Shortcode" title="%s" target="_blank">%s</a>.', 
								  __('See the complete documentation of Shorcodes in Wordpress.org', 'spanish-quotes-of-the-day'),
								  __('Wordpress Shortcodes', 'spanish-quotes-of-the-day')
								);
				
				$out .= '</p>';
				echo $out;
				break;
				
			case 'settings-page' :
				// Settings Page
				$out  = sprintf( '<h4>%s</h4>', __('Settings Page', 'spanish-quotes-of-the-day'));
				$out .= sprintf( '<p>%s <a href="%s" target="_blank"><strong>%s</strong></a>.</p>', 
								__('To modify the plugin\'s settings, go to Settings >', 'spanish-quotes-of-the-day'),
								admin_url( 'options-general.php?page=spanish_quotes_settings'),
								__('Spanish Quotes' , 'spanish-quotes-of-the-day')
								);
				echo $out;
				break;
				
			case 'calling-plugin-via-function' :
				// Via function
				$out  = sprintf ( '<h4>%s</h4>', __('Calling to the plugin via function', 'spanish-quotes-of-the-day') );
				$out .= sprintf ( '<p>%s <strong>%s</strong> %s <a href="http://codex.wordpress.org/Function_Reference/do_shortcode" title="%s" _target="_blank">%s</a> %s</p>', 
								__('Finally, if you are one of those who believe that <em>Code is Poetry</em>, remeber that you can add', 'spanish-quotes-of-the-day'),
								__('Spanish Quote of the Day', 'spanish-quotes-of-the-day'),
								__('in everyplace of your website with the function', 'spanish-quotes-of-the-day'),
								__('See the complete documentation of do_shortcode() in Wordpress.org', 'spanish-quotes-of-the-day'),
								__('do_shortcode()', 'spanish-quotes-of-the-day'), 
								__('in that way:', 'spanish-quotes-of-the-day')
								);
				$out .= '<pre>';
				$out .= sprintf ( '%s', '&nbsp;&nbsp;&nbsp;<span style="color:#f00; font-weight:bold">&lt;?php</span> <span style="color:#00F">echo</span> do_shortcode(<span style="color:#C00">\'[spanish_quote]\'</span>); <span style="color:#f00; font-weight:bold">?&gt;</span>' );
				
				if ( WPLANG != 'en_US' ) {			
					$out .= sprintf ( '   %s   %s%s%s', 
									 __('or the translated version'),
									 '<span style="color:#f00; font-weight:bold">&lt;?php</span> <span style="color:#00F">echo</span> do_shortcode(<span style="color:#C00">\'[', 
									__( 'spanish_quote', 'spanish-quotes-of-the-day'),
									']\'</span>); <span style="color:#F00; font-weight:bold">?&gt;</span>'
									 );
				}
				$out .= '</pre>';
				echo $out;
				break;

			case 'documentation' :
				// More Information
				$out  = sprintf ( '<h3>%s</h3>', __('Documentation', 'spanish-quotes-of-the-day') );
				$out .= sprintf ( '<p>%s <a href="http://wordpress.org/plugins/spanish-quote-of-the-day-frase-del-dia/" title="%s" target="_blank">%s</a>.</p>', 
								  __('For for more information, please, see complete documentacion in the', 'spanish-quotes-of-the-day'),
								  __('Wordpress plugin\'s page', 'spanish-quotes-of-the-day'), 
								  __('Wordpress plugin\'s page', 'spanish-quotes-of-the-day')
								  );
				echo $out;
				break;
				
			case 'what-is-new' :
				// section What is new
				$out = sprintf ( '<h3>%s %s</h3>', __('What\'s new in version', 'spanish-quotes-of-the-day'), $spn_quotes_ver );
				echo $out;
				break;

			/*
			 * SECTION: What's new in version X messages
			 */
			case 'maximum-length' :
				// v 1.2.2 - Maximum Quote Control, general
				$out  = sprintf ( '<h4>%s</h4>',  __('Maximum length control', 'spanish-quotes-of-the-day'));
				$out .= sprintf ( '<p>%s <a href="http://todopensamientos.com" target="_blank" title="%s"><strong>%s</strong></a>.<br />%s</p>', 
								  __('Until now, the maximun length for the quotes was permanently set to <strong>275</strong> characters but now, if you want, you can receive longer or shorter quotes from' , 'spanish-quotes-of-the-day'), 
								  __( 'Theme classified notable quotes in spanish | TodoPensamientos', 'spanish-quotes-of-the-day' ),
								  'Todopensamientos.com',
								  __('Please, go to <strong>Settings Page</strong> to choose the <strong>maximum length</strong> for the quotes.', 'spanish-quotes-of-the-day')
								  );
				echo $out;
				break;
				
		}

	}

}


// Register and load the widget
function quotes_load_widget() {
	register_widget( 'spn_quotes' );
}
add_action( 'widgets_init', 'quotes_load_widget');

// Initial message on activation
register_activation_hook( __FILE__ , array( 'spn_quotes', 'on_activation' ));
add_action ('admin_notices', array( 'spn_quotes', 'on_activation_msg'));

// REading the local translations
function load_translations() {
	load_plugin_textdomain('spanish-quotes-of-the-day', false, basename( dirname( __FILE__ ) ) . '/languages' );
}
add_action('plugins_loaded', 'load_translations');

// fornating the output
add_filter ('widget_quotes', array( 'spn_quotes', 'cook_quotes'), 10, 2 );
add_filter ('post_quotes',	 array( 'spn_quotes', 'cook_quotes'), 10, 2 );

/*
 * Only for documentation
 *
 * if yout need to remove the basic filter fot a big custom formating you
 * can use the next instrucctions.
 */
//	remove_filter ( 'widget_quotes', array ('spn_quotes', 'cook_quotes'), 10 );
//	remove_filter ( 'post_quotes', array ('spn_quotes', 'cook_quotes'), 10 );